@@ -72,7 +72,7 @@ from .responses import *
 import base64
 from Crypto.Cipher import Blowfish
 
-BASE_URL = "https://gdcportalgw.its-mo.com/api_v190426_NE/gdc/"
+BASE_URL = "https://gdcportalgw.its-mo.com/api_v210707_NE/gdc/"
 
 log = logging.getLogger(__name__)
 
@@ -134,7 +134,9 @@ class Session(object):
 
         try:
             sess = requests.Session()
-            response = sess.send(req)
+            # Nissan servers sometimes do not respond. 
+            # Connections seem OK, but reads are slow and may not be successful
+            response = sess.send(req, timeout=(5.0, 600.0))
             log.debug('Response HTTP Status Code: {status_code}'.format(
                 status_code=response.status_code))
             log.debug('Response HTTP Response Body: {content}'.format(
